/**
 * \file
 * \author Matthias Riedl
 * \brief covers the functionality of a limits_alarm FB
 * \verbatim
 * $id
 * \endverbatim
 */

#ifndef __LIMITS_ALARM_H
#define __LIMITS_ALARM_H

//com

//std

// own
#include "fb.h"
#include "hysteresis.h"

class limits_alarm: public fb
{
  // no copy or assignment operations
  limits_alarm(const limits_alarm& obj);
  limits_alarm& operator=(const limits_alarm& obj);
public:
	/** \name Construct/Destructor */
	//! \{
  	/**
   	 * Constructor
	 */
	limits_alarm();
	/**
	 * Destructor
	 */
	virtual ~limits_alarm();
	//! \}

	/**
	 * Perfoms the algorithm of the function block
	 */
	virtual void 	en();
	
	float	m_h; /**< higher bound */
  float m_l; /**< lower boun */ 
	float	m_x; /**< process value */
	float	m_eps; /**< confidential interval */

	float	m_q; /**< output; true - value is inside the confidence interval */
  float	m_qh; /**< output; true - value is beyound the higher bound */
  float	m_ql; /**< output; true - value is beyound the lower bound */
private:
  float m_eps_2; /**< half of the confidence interval */
  hysteresis  m_high_alarm; /**< check, if pv exceeds high limit */
  hysteresis  m_low_alarm; /**< check, if pv falls below low limit */
};

#endif  //__LIMITS_ALARM_H
